@@ -34,7 +34,7 @@ class ContinuousOffPolicyEvaluation:
     Parameters
     -----------
     bandit_feedback: BanditFeedback
-        Logged bandit feedback data with continuous actions used to conduct OPE.
+        Logged bandit data with continuous actions used to conduct OPE.
 
     ope_estimators: List[BaseOffPolicyEstimator]
         List of OPE estimators used to evaluate the policy value of evaluation policy.
@@ -183,15 +183,15 @@ class ContinuousOffPolicyEvaluation:
             Continuous action values given by evaluation policy, i.e., :math:`\\pi_e(x_t)`.
 
         estimated_rewards_by_reg_model: array-like, shape (n_rounds,) or Dict[str, array-like], default=None
-            Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+            Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
             When an array-like is given, all OPE estimators use it.
-            When a dict is given, if the dict has the name of a estimator as a key, the corresponding value is used.
-            When it is not given, model-dependent estimators such as DM and DR cannot be used.
+            When a dict with an estimator's name as its key is given, the corresponding value is used for the estimator.
+            If None, model-dependent estimators such as DM and DR cannot be used.
 
         Returns
         ----------
         policy_value_dict: Dict[str, float]
-            Dictionary containing estimated policy values by OPE estimators.
+            Dictionary containing the policy values estimated by OPE estimators.
 
         """
         if self.is_model_dependent:
@@ -222,7 +222,7 @@ class ContinuousOffPolicyEvaluation:
         n_bootstrap_samples: int = 100,
         random_state: Optional[int] = None,
     ) -> Dict[str, Dict[str, float]]:
-        """Estimate confidence intervals of policy values by nonparametric bootstrap procedure.
+        """Estimate confidence intervals of policy values using nonparametric bootstrap.
 
         Parameters
         ------------
@@ -230,16 +230,16 @@ class ContinuousOffPolicyEvaluation:
             Continuous action values given by the (deterministic) evaluation policy, i.e., :math:`\\pi_e(x_t)`.
 
         estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list) or Dict[str, array-like], default=None
-            Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+            Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
             When an array-like is given, all OPE estimators use it.
-            When a dict is given, if the dict has the name of a estimator as a key, the corresponding value is used.
-            When it is not given, model-dependent estimators such as DM and DR cannot be used.
+            When a dict with an estimator's name as its key is given, the corresponding value is used for the estimator.
+            If None, model-dependent estimators such as DM and DR cannot be used.
 
         alpha: float, default=0.05
             Significance level.
 
         n_bootstrap_samples: int, default=100
-            Number of resampling performed in the bootstrap procedure.
+            Number of resampling performed in bootstrap sampling.
 
         random_state: int, default=None
             Controls the random seed in bootstrap sampling.
@@ -247,8 +247,7 @@ class ContinuousOffPolicyEvaluation:
         Returns
         ----------
         policy_value_interval_dict: Dict[str, Dict[str, float]]
-            Dictionary containing confidence intervals of estimated policy value estimated
-            using nonparametric bootstrap procedure.
+            Dictionary containing confidence intervals of the estimated policy values.
 
         """
         if self.is_model_dependent:
@@ -295,16 +294,16 @@ class ContinuousOffPolicyEvaluation:
             Continuous action values given by the (deterministic) evaluation policy, i.e., :math:`\\pi_e(x_t)`.
 
         estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list) or Dict[str, array-like], default=None
-            Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+            Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
             When an array-like is given, all OPE estimators use it.
-            When a dict is given, if the dict has the name of a estimator as a key, the corresponding value is used.
-            When it is not given, model-dependent estimators such as DM and DR cannot be used.
+            When a dict with an estimator's name as its key is given, the corresponding value is used for the estimator.
+            If None, model-dependent estimators such as DM and DR cannot be used.
 
         alpha: float, default=0.05
             Significance level.
 
         n_bootstrap_samples: int, default=100
-            Number of resampling performed in the bootstrap procedure.
+            Number of resampling performed in bootstrap sampling.
 
         random_state: int, default=None
             Controls the random seed in bootstrap sampling.
@@ -357,7 +356,7 @@ class ContinuousOffPolicyEvaluation:
         fig_dir: Optional[Path] = None,
         fig_name: str = "estimated_policy_value.png",
     ) -> None:
-        """Visualize policy values estimated by OPE estimators.
+        """Visualize the estimated policy values.
 
         Parameters
         ----------
@@ -365,16 +364,16 @@ class ContinuousOffPolicyEvaluation:
             Continuous action values given by the (deterministic) evaluation policy, i.e., :math:`\\pi_e(x_t)`.
 
         estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list) or Dict[str, array-like], default=None
-            Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+            Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
             When an array-like is given, all OPE estimators use it.
-            When a dict is given, if the dict has the name of a estimator as a key, the corresponding value is used.
-            When it is not given, model-dependent estimators such as DM and DR cannot be used.
+            When a dict with an estimator's name as its key is given, the corresponding value is used for the estimator.
+            If None, model-dependent estimators such as DM and DR cannot be used.
 
         alpha: float, default=0.05
             Significance level.
 
         n_bootstrap_samples: int, default=100
-            Number of resampling performed in the bootstrap procedure.
+            Number of resampling performed in bootstrap sampling.
 
         random_state: int, default=None
             Controls the random seed in bootstrap sampling.
@@ -385,16 +384,16 @@ class ContinuousOffPolicyEvaluation:
 
         fig_dir: Path, default=None
             Path to store the bar figure.
-            If 'None' is given, the figure will not be saved.
+            If None, the figure will not be saved.
 
         fig_name: str, default="estimated_policy_value.png"
             Name of the bar figure.
 
         """
         if fig_dir is not None:
-            assert isinstance(fig_dir, Path), "fig_dir must be a Path"
+            assert isinstance(fig_dir, Path), "`fig_dir` must be a Path"
         if fig_name is not None:
-            assert isinstance(fig_name, str), "fig_dir must be a string"
+            assert isinstance(fig_name, str), "`fig_dir` must be a string"
 
         estimated_round_rewards_dict = dict()
         estimator_inputs = self._create_estimator_inputs(
@@ -424,7 +423,7 @@ class ContinuousOffPolicyEvaluation:
         )
         plt.xlabel("OPE Estimators", fontsize=25)
         plt.ylabel(
-            f"Estimated Policy Value (± {np.int(100*(1 - alpha))}% CI)", fontsize=20
+            f"Estimated Policy Value (± {np.int32(100*(1 - alpha))}% CI)", fontsize=20
         )
         plt.yticks(fontsize=15)
         plt.xticks(fontsize=25 - 2 * len(self.ope_estimators))
@@ -439,13 +438,13 @@ class ContinuousOffPolicyEvaluation:
         estimated_rewards_by_reg_model: Optional[
             Union[np.ndarray, Dict[str, np.ndarray]]
         ] = None,
-        metric: str = "relative-ee",
+        metric: str = "se",
     ) -> Dict[str, float]:
-        """Evaluate estimation performance of OPE estimators.
+        """Evaluate the accuracy of OPE estimators.
 
         Note
         ------
-        Evaluate the estimation performance of OPE estimators by relative estimation error (relative-EE) or squared error (SE):
+        Evaluate the estimation performance of OPE estimators with relative estimation error (relative-EE) or squared error (SE):
 
         .. math ::
             \\text{Relative-EE} (\\hat{V}; \\mathcal{D}) = \\left|  \\frac{\\hat{V}(\\pi; \\mathcal{D}) - V(\\pi)}{V(\\pi)} \\right|,
@@ -454,7 +453,7 @@ class ContinuousOffPolicyEvaluation:
             \\text{SE} (\\hat{V}; \\mathcal{D}) = \\left(\\hat{V}(\\pi; \\mathcal{D}) - V(\\pi) \\right)^2,
 
         where :math:`V({\\pi})` is the ground-truth policy value of the evalation policy :math:`\\pi_e` (often estimated using on-policy estimation).
-        :math:`\\hat{V}(\\pi; \\mathcal{D})` is an estimated policy value by an OPE estimator :math:`\\hat{V}` and logged bandit feedback :math:`\\mathcal{D}`.
+        :math:`\\hat{V}(\\pi; \\mathcal{D})` is the policy value estimated by an OPE estimator :math:`\\hat{V}` and logged bandit feedback :math:`\\mathcal{D}`.
 
         Parameters
         ----------
@@ -466,19 +465,19 @@ class ContinuousOffPolicyEvaluation:
             Continuous action values given by the (deterministic) evaluation policy, i.e., :math:`\\pi_e(x_t)`.
 
         estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list) or Dict[str, array-like], default=None
-            Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+            Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
             When an array-like is given, all OPE estimators use it.
-            When a dict is given, if the dict has the name of a estimator as a key, the corresponding value is used.
-            When it is not given, model-dependent estimators such as DM and DR cannot be used.
+            When a dict with an estimator's name as its key is given, the corresponding value is used for the estimator.
+            If None, model-dependent estimators such as DM and DR cannot be used.
 
-        metric: str, default="relative-ee"
-            Evaluation metric to evaluate and compare the estimation performance of OPE estimators.
-            Must be "relative-ee" or "se".
+        metric: str, default="se"
+            Results of performance comparison among OPE estimators.
+            Must be either "relative-ee" or "se".
 
         Returns
         ----------
         eval_metric_ope_dict: Dict[str, float]
-            Dictionary containing evaluation metric for evaluating the estimation performance of OPE estimators.
+            Dictionary containing the value of evaluation metric for the estimation performance of OPE estimators.
 
         """
 
@@ -489,11 +488,11 @@ class ContinuousOffPolicyEvaluation:
         )
         if metric not in ["relative-ee", "se"]:
             raise ValueError(
-                f"metric must be either 'relative-ee' or 'se', but {metric} is given"
+                f"`metric` must be either 'relative-ee' or 'se', but {metric} is given"
             )
         if metric == "relative-ee" and ground_truth_policy_value == 0.0:
             raise ValueError(
-                "ground_truth_policy_value must be non-zero when metric is relative-ee"
+                "`ground_truth_policy_value` must be non-zero when metric is relative-ee"
             )
 
         eval_metric_ope_dict = dict()
@@ -521,7 +520,7 @@ class ContinuousOffPolicyEvaluation:
         estimated_rewards_by_reg_model: Optional[
             Union[np.ndarray, Dict[str, np.ndarray]]
         ] = None,
-        metric: str = "relative-ee",
+        metric: str = "se",
     ) -> DataFrame:
         """Summarize performance comparison of OPE estimators.
 
@@ -535,17 +534,17 @@ class ContinuousOffPolicyEvaluation:
             Continuous action values given by the (deterministic) evaluation policy, i.e., :math:`\\pi_e(x_t)`.
 
         estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list), default=None
-            Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
-            When it is not given, model-dependent estimators such as DM and DR cannot be used.
+            Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
+            If None, model-dependent estimators such as DM and DR cannot be used.
 
-        metric: str, default="relative-ee"
-            Evaluation metric to evaluate and compare the estimation performance of OPE estimators.
+        metric: str, default="se"
+            Results of performance comparison among OPE estimators.
             Must be either "relative-ee" or "se".
 
         Returns
         ----------
         eval_metric_ope_df: DataFrame
-            Evaluation metric to evaluate and compare the estimation performance of OPE estimators.
+            Results of performance comparison among OPE estimators.
 
         """
         eval_metric_ope_df = DataFrame(
@@ -573,7 +572,7 @@ class ContinuousOffPolicyEvaluation:
         fig_dir: Optional[Path] = None,
         fig_name: str = "estimated_policy_value.png",
     ) -> None:
-        """Visualize policy values estimated by OPE estimators.
+        """Visualize the estimated policy values.
 
         Parameters
         ----------
@@ -584,16 +583,16 @@ class ContinuousOffPolicyEvaluation:
             List of action values given by the (deterministic) evaluation policies, i.e., :math:`\\pi_e(x_t)`.
 
         estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list) or Dict[str, array-like], default=None
-            Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+            Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
             When an array-like is given, all OPE estimators use it.
             When a dict is given, if the dict has the name of an estimator as a key, the corresponding value is used.
-            When it is not given, model-dependent estimators such as DM and DR cannot be used.
+            If None, model-dependent estimators such as DM and DR cannot be used.
 
         alpha: float, default=0.05
             Significance level.
 
         n_bootstrap_samples: int, default=100
-            Number of resampling performed in the bootstrap procedure.
+            Number of resampling performed in bootstrap sampling.
 
         random_state: int, default=None
             Controls the random seed in bootstrap sampling.
@@ -604,7 +603,7 @@ class ContinuousOffPolicyEvaluation:
 
         fig_dir: Path, default=None
             Path to store the bar figure.
-            If 'None' is given, the figure will not be saved.
+            If None, the figure will not be saved.
 
         fig_name: str, default="estimated_policy_value.png"
             Name of the bar figure.
@@ -615,9 +614,9 @@ class ContinuousOffPolicyEvaluation:
                 "the length of policy_name_list must be the same as action_by_evaluation_policy_list"
             )
         if fig_dir is not None:
-            assert isinstance(fig_dir, Path), "fig_dir must be a Path"
+            assert isinstance(fig_dir, Path), "`fig_dir` must be a Path"
         if fig_name is not None:
-            assert isinstance(fig_name, str), "fig_dir must be a string"
+            assert isinstance(fig_name, str), "`fig_dir` must be a string"
 
         estimated_round_rewards_dict = {
             estimator_name: {} for estimator_name in self.ope_estimators_
@@ -657,7 +656,8 @@ class ContinuousOffPolicyEvaluation:
             )
             ax.set_title(estimator_name.upper(), fontsize=20)
             ax.set_ylabel(
-                f"Estimated Policy Value (± {np.int(100*(1 - alpha))}% CI)", fontsize=20
+                f"Estimated Policy Value (± {np.int32(100*(1 - alpha))}% CI)",
+                fontsize=20,
             )
             plt.yticks(fontsize=15)
             plt.xticks(fontsize=25 - 2 * len(policy_name_list))
