@@ -4,17 +4,23 @@
 """Bandit Simulator."""
 from copy import deepcopy
 from typing import Callable
+from typing import Union
 
 import numpy as np
 from tqdm import tqdm
 
+from ..policy import BaseContextFreePolicy
+from ..policy import BaseContextualPolicy
 from ..policy.policy_type import PolicyType
 from ..types import BanditFeedback
-from ..types import BanditPolicy
 from ..utils import check_bandit_feedback_inputs
 from ..utils import convert_to_action_dist
 
 
+# bandit policy type
+BanditPolicy = Union[BaseContextFreePolicy, BaseContextualPolicy]
+
+
 def run_bandit_simulation(
     bandit_feedback: BanditFeedback, policy: BanditPolicy
 ) -> np.ndarray:
@@ -23,10 +29,10 @@ def run_bandit_simulation(
     Parameters
     ----------
     bandit_feedback: BanditFeedback
-        Logged bandit feedback data used in offline bandit simulation.
+        Logged bandit data used in offline bandit simulation.
 
     policy: BanditPolicy
-        Online bandit policy evaluated in offline bandit simulation (i.e., evaluation policy).
+        Online bandit policy to be evaluated in offline bandit simulation (i.e., evaluation policy).
 
     Returns
     --------
@@ -99,15 +105,13 @@ def calc_ground_truth_policy_value(
     Parameters
     ----------
     bandit_feedback: BanditFeedback
-        Logged bandit feedback data used in offline bandit simulation.
-        It must contain "expected_rewards".
+        Logged bandit data used in offline bandit simulation. Must contain "expected_rewards" as a key.
 
     reward_sampler: Callable[[np.ndarray, np.ndarray], np.ndarray]
-        Function sampling reward for each given action-context pair,
-        i.e., :math:`p(r \\mid x, a)`.
+        Function sampling reward for each given action-context pair, i.e., :math:`p(r|x, a)`.
 
     policy: BanditPolicy
-        Online bandit policy evaluated in offline bandit simulation (i.e., evaluation policy).
+        Online bandit policy to be evaluated in offline bandit simulation (i.e., evaluation policy).
 
     n_sim: int, default=100
         Number of simulations in the Monte Carlo simulation to compute the policy value.
@@ -116,6 +120,7 @@ def calc_ground_truth_policy_value(
     --------
     ground_truth_policy_value: float
         policy value of a given evaluation policy.
+
     """
     for key_ in [
         "action",
