@@ -26,7 +26,7 @@ def check_confidence_interval_arguments(
         Significance level.
 
     n_bootstrap_samples: int, default=10000
-        Number of resampling performed in the bootstrap procedure.
+        Number of resampling performed in bootstrap sampling.
 
     random_state: int, default=None
         Controls the random seed in bootstrap sampling.
@@ -48,7 +48,7 @@ def estimate_confidence_interval_by_bootstrap(
     n_bootstrap_samples: int = 10000,
     random_state: Optional[int] = None,
 ) -> Dict[str, float]:
-    """Estimate confidence interval by nonparametric bootstrap-like procedure.
+    """Estimate confidence interval using nonparametric bootstrap.
 
     Parameters
     ----------
@@ -59,7 +59,7 @@ def estimate_confidence_interval_by_bootstrap(
         Significance level.
 
     n_bootstrap_samples: int, default=10000
-        Number of resampling performed in the bootstrap procedure.
+        Number of resampling performed in bootstrap sampling.
 
     random_state: int, default=None
         Controls the random seed in bootstrap sampling.
@@ -126,8 +126,8 @@ def convert_to_action_dist(
         Number of actions.
 
     selected_actions: array-like, shape (n_rounds, len_list)
-            Sequence of actions selected by evaluation policy
-            at each round in offline bandit simulation.
+        Sequence of actions selected by evaluation policy
+        at each round in offline bandit simulation.
 
     Returns
     ----------
@@ -167,10 +167,12 @@ def check_array(
 
     """
     if not isinstance(array, np.ndarray):
-        raise ValueError(f"{name} must be {expected_dim}D array, but got {type(array)}")
+        raise ValueError(
+            f"`{name}` must be {expected_dim}D array, but got {type(array)}"
+        )
     if array.ndim != expected_dim:
         raise ValueError(
-            f"{name} must be {expected_dim}D array, but got {array.ndim}D array"
+            f"`{name}` must be {expected_dim}D array, but got {array.ndim}D array"
         )
 
 
@@ -195,11 +197,11 @@ def check_tensor(
     """
     if not isinstance(tensor, torch.Tensor):
         raise ValueError(
-            f"{name} must be {expected_dim}D tensor, but got {type(tensor)}"
+            f"`{name}` must be {expected_dim}D tensor, but got {type(tensor)}"
         )
     if tensor.ndim != expected_dim:
         raise ValueError(
-            f"{name} must be {expected_dim}D tensor, but got {tensor.ndim}D tensor"
+            f"`{name}` must be {expected_dim}D tensor, but got {tensor.ndim}D tensor"
         )
 
 
@@ -217,23 +219,22 @@ def check_bandit_feedback_inputs(
     Parameters
     -----------
     context: array-like, shape (n_rounds, dim_context)
-        Context vectors in each round, i.e., :math:`x_t`.
+        Context vectors observed for each data, i.e., :math:`x_i`.
 
     action: array-like, shape (n_rounds,)
-        Action sampled by behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
+        Actions sampled by behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
     reward: array-like, shape (n_rounds,)
-        Observed rewards (or outcome) in each round, i.e., :math:`r_t`.
+        Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
 
     expected_reward: array-like, shape (n_rounds, n_actions), default=None
-        Expected rewards (or outcome) in each round, i.e., :math:`\\mathbb{E}[r_t]`.
+        Expected reward of each data, i.e., :math:`\\mathbb{E}[r_i|x_i,a_i]`.
 
     position: array-like, shape (n_rounds,), default=None
-        Position of recommendation interface where action was presented in each round of the given logged bandit data.
+        Indices to differentiate positions in a recommendation interface where the actions are presented.
 
-    pscore: array-like, shape (n_rounds,), default=None
-        Propensity scores, the probability of selecting each action by behavior policy,
-        in the given logged bandit data.
+    pscore: array-like, shape (n_rounds,)
+        Action choice probabilities of behavior policy (propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
 
     action_context: array-like, shape (n_actions, dim_action_context)
         Context vectors characterizing each action.
@@ -242,9 +243,6 @@ def check_bandit_feedback_inputs(
     check_array(array=context, name="context", expected_dim=2)
     check_array(array=action, name="action", expected_dim=1)
     check_array(array=reward, name="reward", expected_dim=1)
-    if not (np.issubdtype(action.dtype, np.integer) and action.min() >= 0):
-        raise ValueError("action elements must be non-negative integers")
-
     if expected_reward is not None:
         check_array(array=expected_reward, name="expected_reward", expected_dim=2)
         if not (
@@ -257,10 +255,17 @@ def check_bandit_feedback_inputs(
                 "Expected `context.shape[0] == action.shape[0] == reward.shape[0] == expected_reward.shape[0]`"
                 ", but found it False"
             )
-        if action.max() >= expected_reward.shape[1]:
+        if not (
+            np.issubdtype(action.dtype, np.integer)
+            and action.min() >= 0
+            and action.max() < expected_reward.shape[1]
+        ):
             raise ValueError(
-                "action elements must be smaller than `expected_reward.shape[1]`"
+                "`action` elements must be integers in the range of [0, `expected_reward.shape[1]`)"
             )
+    else:
+        if not (np.issubdtype(action.dtype, np.integer) and action.min() >= 0):
+            raise ValueError("`action` elements must be non-negative integers")
     if pscore is not None:
         check_array(array=pscore, name="pscore", expected_dim=1)
         if not (
@@ -271,7 +276,7 @@ def check_bandit_feedback_inputs(
                 ", but found it False"
             )
         if np.any(pscore <= 0):
-            raise ValueError("pscore must be positive")
+            raise ValueError("`pscore` must be positive")
 
     if position is not None:
         check_array(array=position, name="position", expected_dim=1)
@@ -283,7 +288,7 @@ def check_bandit_feedback_inputs(
                 ", but found it False"
             )
         if not (np.issubdtype(position.dtype, np.integer) and position.min() >= 0):
-            raise ValueError("position elements must be non-negative integers")
+            raise ValueError("`position` elements must be non-negative integers")
     else:
         if not (context.shape[0] == action.shape[0] == reward.shape[0]):
             raise ValueError(
@@ -292,10 +297,17 @@ def check_bandit_feedback_inputs(
             )
     if action_context is not None:
         check_array(array=action_context, name="action_context", expected_dim=2)
-        if action.max() >= action_context.shape[0]:
+        if not (
+            np.issubdtype(action.dtype, np.integer)
+            and action.min() >= 0
+            and action.max() < action_context.shape[0]
+        ):
             raise ValueError(
-                "action elements must be smaller than `action_context.shape[0]`"
+                "`action` elements must be integers in the range of [0, `action_context.shape[0]`)"
             )
+    else:
+        if not (np.issubdtype(action.dtype, np.integer) and action.min() >= 0):
+            raise ValueError("`action` elements must be non-negative integers")
 
 
 def check_ope_inputs(
@@ -305,35 +317,37 @@ def check_ope_inputs(
     reward: Optional[np.ndarray] = None,
     pscore: Optional[np.ndarray] = None,
     estimated_rewards_by_reg_model: Optional[np.ndarray] = None,
+    estimated_importance_weights: Optional[np.ndarray] = None,
 ) -> Optional[ValueError]:
     """Check inputs for ope.
 
     Parameters
     -----------
     action_dist: array-like, shape (n_rounds, n_actions, len_list)
-        Action choice probabilities of evaluation policy (can be deterministic), i.e., :math:`\\pi_e(a_t|x_t)`.
+        Action choice probabilities of evaluation policy (can be deterministic), i.e., :math:`\\pi_e(a_i|x_i)`.
 
     position: array-like, shape (n_rounds,), default=None
-        Position of recommendation interface where action was presented in each round of the given logged bandit data.
+        Indices to differentiate positions in a recommendation interface where the actions are presented.
 
     action: array-like, shape (n_rounds,), default=None
-        Action sampled by behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
+        Actions sampled by behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
     reward: array-like, shape (n_rounds,), default=None
-        Observed rewards (or outcome) in each round, i.e., :math:`r_t`.
+        Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
 
-    pscore: array-like, shape (n_rounds,), default=None
-        Propensity scores, the probability of selecting each action by behavior policy,
-        in the given logged bandit data.
+    pscore: array-like, shape (n_rounds,)
+            Action choice probabilities of behavior policy (propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
 
     estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list), default=None
-        Expected rewards given context, action, and position estimated by regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+        Estimated expected rewards given context, action, and position, i.e., :math:`\\hat{q}(x_i,a_i)`.
 
+    estimated_importance_weights: array-like, shape (n_rounds,), default=None
+        Importance weights estimated via supervised classification, i.e., :math:`\\hat{w}(x_t, a_t)`.
     """
     # action_dist
     check_array(array=action_dist, name="action_dist", expected_dim=3)
     if not np.allclose(action_dist.sum(axis=1), 1):
-        raise ValueError("action_dist must be a probability distribution")
+        raise ValueError("`action_dist` must be a probability distribution")
 
     # position
     if position is not None:
@@ -343,14 +357,14 @@ def check_ope_inputs(
                 "Expected `position.shape[0] == action_dist.shape[0]`, but found it False"
             )
         if not (np.issubdtype(position.dtype, np.integer) and position.min() >= 0):
-            raise ValueError("position elements must be non-negative integers")
+            raise ValueError("`position` elements must be non-negative integers")
         if position.max() >= action_dist.shape[2]:
             raise ValueError(
-                "position elements must be smaller than `action_dist.shape[2]`"
+                "`position` elements must be smaller than `action_dist.shape[2]`"
             )
     elif action_dist.shape[2] > 1:
         raise ValueError(
-            "position elements must be given when `action_dist.shape[2] > 1`"
+            "`position` elements must be given when `action_dist.shape[2] > 1`"
         )
 
     # estimated_rewards_by_reg_model
@@ -360,6 +374,14 @@ def check_ope_inputs(
                 "Expected `estimated_rewards_by_reg_model.shape == action_dist.shape`, but found it False"
             )
 
+    if estimated_importance_weights is not None:
+        if not (action.shape[0] == estimated_importance_weights.shape[0]):
+            raise ValueError(
+                "Expected `action.shape[0] == estimated_importance_weights.shape[0]`, but found it False"
+            )
+        if np.any(estimated_importance_weights < 0):
+            raise ValueError("estimated_importance_weights must be non-negative")
+
     # action, reward
     if action is not None or reward is not None:
         check_array(array=action, name="action", expected_dim=1)
@@ -368,11 +390,13 @@ def check_ope_inputs(
             raise ValueError(
                 "Expected `action.shape[0] == reward.shape[0]`, but found it False"
             )
-        if not (np.issubdtype(action.dtype, np.integer) and action.min() >= 0):
-            raise ValueError("action elements must be non-negative integers")
-        if action.max() >= action_dist.shape[1]:
+        if not (
+            np.issubdtype(action.dtype, np.integer)
+            and action.min() >= 0
+            and action.max() < action_dist.shape[1]
+        ):
             raise ValueError(
-                "action elements must be smaller than `action_dist.shape[1]`"
+                "`action` elements must be integers in the range of [0, `action_dist.shape[1]`)"
             )
 
     # pscore
@@ -384,7 +408,7 @@ def check_ope_inputs(
                 "Expected `action.shape[0] == reward.shape[0] == pscore.shape[0]`, but found it False"
             )
         if np.any(pscore <= 0):
-            raise ValueError("pscore must be positive")
+            raise ValueError("`pscore` must be positive")
 
 
 def check_continuous_bandit_feedback_inputs(
@@ -399,20 +423,20 @@ def check_continuous_bandit_feedback_inputs(
     Parameters
     -----------
     context: array-like, shape (n_rounds, dim_context)
-        Context vectors in each round, i.e., :math:`x_t`.
+        Context vectors observed for each data, i.e., :math:`x_i`.
 
     action_by_behavior_policy: array-like, shape (n_rounds,)
-        Continuous action values sampled by a behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
+        Continuous action values sampled by a behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
     reward: array-like, shape (n_rounds,)
-        Observed rewards (or outcome) in each round, i.e., :math:`r_t`.
+        Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
 
     expected_reward: array-like, shape (n_rounds, n_actions), default=None
-        Expected rewards (or outcome) in each round, i.e., :math:`\\mathbb{E}[r_t]`.
+        Expected reward of each data, i.e., :math:`\\mathbb{E}[r_i|x_i,a_i]`.
 
     pscore: array-like, shape (n_rounds,), default=None
         Probability densities of the continuous action values sampled by a behavior policy
-        (generalized propensity scores), i.e., :math:`\\pi_b(a_t|x_t)`.
+        (generalized propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
 
     """
     check_array(array=context, name="context", expected_dim=2)
@@ -448,7 +472,7 @@ def check_continuous_bandit_feedback_inputs(
                 "== reward.shape[0] == pscore.shape[0]`, but found it False"
             )
         if np.any(pscore <= 0):
-            raise ValueError("pscore must be positive")
+            raise ValueError("`pscore` must be positive")
 
 
 def check_continuous_ope_inputs(
@@ -466,17 +490,17 @@ def check_continuous_ope_inputs(
         Continuous action values given by the evaluation policy (can be deterministic), i.e., :math:`\\pi_e(x_t)`.
 
     action_by_behavior_policy: array-like, shape (n_rounds,), default=None
-        Continuous action values sampled by a behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
+        Continuous action values sampled by a behavior policy for each data in logged bandit data, i.e., :math:`a_i`.
 
     reward: array-like, shape (n_rounds,), default=None
-        Observed rewards (or outcome) in each round, i.e., :math:`r_t`.
+        Rewards observed for each data in logged bandit data, i.e., :math:`r_i`.
 
     pscore: array-like, shape (n_rounds,), default=None
         Probability densities of the continuous action values sampled by a behavior policy
-        (generalized propensity scores), i.e., :math:`\\pi_b(a_t|x_t)`.
+        (generalized propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
 
     estimated_rewards_by_reg_model: array-like, shape (n_rounds,), default=None
-            Expected rewards given context and action estimated by a regression model, i.e., :math:`\\hat{q}(x_t,a_t)`.
+        Expected rewards given context and action estimated by a regression model, i.e., :math:`\\hat{q}(x_i,a_i)`.
 
     """
     # action_by_evaluation_policy
@@ -534,7 +558,7 @@ def check_continuous_ope_inputs(
                 ", but found it False"
             )
         if np.any(pscore <= 0):
-            raise ValueError("pscore must be positive")
+            raise ValueError("`pscore` must be positive")
 
 
 def _check_slate_ope_inputs(
@@ -550,13 +574,13 @@ def _check_slate_ope_inputs(
     Parameters
     -----------
     slate_id: array-like, shape (<= n_rounds * len_list,)
-        Slate id observed in each round of the logged bandit feedback.
+        Slate id observed for each data in logged bandit data.
 
     reward: array-like, shape (<= n_rounds * len_list,)
-        Reward observed at each slot in each round of the logged bandit feedback, i.e., :math:`r_{t}(k)`.
+        Slot-level rewards, i.e., :math:`r_{i}(l)`.
 
     position: array-like, shape (<= n_rounds * len_list,)
-        Positions of each round and slot in the given logged bandit data.
+        Indices to differentiate positions in a recommendation interface where the actions are presented.
 
     pscore: array-like, shape (<= n_rounds * len_list,)
         Action choice probabilities of behavior policy (propensity scores).
@@ -571,7 +595,7 @@ def _check_slate_ope_inputs(
     # position
     check_array(array=position, name="position", expected_dim=1)
     if not (position.dtype == int and position.min() >= 0):
-        raise ValueError("position elements must be non-negative integers")
+        raise ValueError("`position` elements must be non-negative integers")
 
     # reward
     check_array(array=reward, name="reward", expected_dim=1)
@@ -579,7 +603,7 @@ def _check_slate_ope_inputs(
     # pscore
     check_array(array=pscore, name=f"{pscore_type}", expected_dim=1)
     if np.any(pscore <= 0) or np.any(pscore > 1):
-        raise ValueError(f"{pscore_type} must be in the range of (0, 1]")
+        raise ValueError(f"`{pscore_type}` must be in the range of (0, 1]")
 
     # evaluation_policy_pscore
     check_array(
@@ -589,7 +613,7 @@ def _check_slate_ope_inputs(
     )
     if np.any(evaluation_policy_pscore < 0) or np.any(evaluation_policy_pscore > 1):
         raise ValueError(
-            f"evaluation_policy_{pscore_type} must be in the range of [0, 1]"
+            f"`evaluation_policy_{pscore_type}` must be in the range of [0, 1]"
         )
 
     # slate id
@@ -604,7 +628,7 @@ def _check_slate_ope_inputs(
         == evaluation_policy_pscore.shape[0]
     ):
         raise ValueError(
-            f"slate_id, position, reward, {pscore_type}, and evaluation_policy_{pscore_type} "
+            f"`slate_id`, `position`, `reward`, `{pscore_type}`, and `evaluation_policy_{pscore_type}` "
             "must have the same number of samples."
         )
 
@@ -621,19 +645,19 @@ def check_sips_inputs(
     Parameters
     -----------
     slate_id: array-like, shape (<= n_rounds * len_list,)
-        Slate id observed in each round of the logged bandit feedback.
+        Slate id observed for each data in logged bandit data.
 
     reward: array-like, shape (<= n_rounds * len_list,)
-        Reward observed at each slot in each round of the logged bandit feedback, i.e., :math:`r_{t}(k)`.
+        Slot-level rewards, i.e., :math:`r_{i}(l)`.
 
     position: array-like, shape (<= n_rounds * len_list,)
-        Positions of each round and slot in the given logged bandit data.
+        Indices to differentiate positions in a recommendation interface where the actions are presented.
 
     pscore: array-like, shape (<= n_rounds * len_list,)
-        Action choice probabilities of behavior policy (propensity scores), i.e., :math:`\\pi_b(a_t|x_t)`.
+        Action choice probabilities of behavior policy (propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
 
     evaluation_policy_pscore: array-like, shape (<= n_rounds * len_list,)
-        Action choice probabilities of evaluation policy, i.e., :math:`\\pi_e(a_t|x_t)`.
+        Action choice probabilities of evaluation policy, i.e., :math:`\\pi_e(a_i|x_i)`.
 
     """
     _check_slate_ope_inputs(
@@ -653,19 +677,19 @@ def check_sips_inputs(
     bandit_feedback_df["evaluation_policy_pscore"] = evaluation_policy_pscore
     # check uniqueness
     if bandit_feedback_df.duplicated(["slate_id", "position"]).sum() > 0:
-        raise ValueError("position must not be duplicated in each slate")
+        raise ValueError("`position` must not be duplicated in each slate")
     # check pscore uniqueness
     distinct_count_pscore_in_slate = bandit_feedback_df.groupby("slate_id").apply(
         lambda x: x["pscore"].unique().shape[0]
     )
     if (distinct_count_pscore_in_slate != 1).sum() > 0:
-        raise ValueError("pscore must be unique in each slate")
+        raise ValueError("`pscore` must be unique in each slate")
     # check pscore uniqueness of evaluation policy
     distinct_count_evaluation_policy_pscore_in_slate = bandit_feedback_df.groupby(
         "slate_id"
     ).apply(lambda x: x["evaluation_policy_pscore"].unique().shape[0])
     if (distinct_count_evaluation_policy_pscore_in_slate != 1).sum() > 0:
-        raise ValueError("evaluation_policy_pscore must be unique in each slate")
+        raise ValueError("`evaluation_policy_pscore` must be unique in each slate")
 
 
 def check_iips_inputs(
@@ -680,19 +704,19 @@ def check_iips_inputs(
     Parameters
     -----------
     slate_id: array-like, shape (<= n_rounds * len_list,)
-        Slate id observed in each round of the logged bandit feedback.
+        Slate id observed for each data in logged bandit data.
 
     reward: array-like, shape (<= n_rounds * len_list,)
-        Reward observed at each slot in each round of the logged bandit feedback, i.e., :math:`r_{t}(k)`.
+        Slot-level rewards, i.e., :math:`r_{i}(l)`.
 
     position: array-like, shape (<= n_rounds * len_list,)
-        Positions of each round and slot in the given logged bandit data.
+        Indices to differentiate positions in a recommendation interface where the actions are presented.
 
     pscore_item_position: array-like, shape (<= n_rounds * len_list,)
-        Marginal action choice probabilities of the slot (:math:`k`) by a behavior policy (propensity scores), i.e., :math:`\\pi_b(a_{t}(k) |x_t)`.
+        Marginal action choice probabilities of the slot (:math:`l`) by a behavior policy (propensity scores), i.e., :math:`\\pi_b(a_{i}(l) |x_i)`.
 
     evaluation_policy_pscore_item_position: array-like, shape (<= n_rounds * len_list,)
-        Marginal action choice probabilities of the slot (:math:`k`) by the evaluation policy, i.e., :math:`\\pi_e(a_{t}(k) |x_t)`.
+        Marginal action choice probabilities of the slot (:math:`l`) by the evaluation policy, i.e., :math:`\\pi_e(a_{i}(l) |x_i)`.
 
     """
     _check_slate_ope_inputs(
@@ -709,7 +733,7 @@ def check_iips_inputs(
     bandit_feedback_df["position"] = position
     # check uniqueness
     if bandit_feedback_df.duplicated(["slate_id", "position"]).sum() > 0:
-        raise ValueError("position must not be duplicated in each slate")
+        raise ValueError("`position` must not be duplicated in each slate")
 
 
 def check_rips_inputs(
@@ -724,19 +748,19 @@ def check_rips_inputs(
     Parameters
     -----------
     slate_id: array-like, shape (<= n_rounds * len_list,)
-        Slate id observed in each round of the logged bandit feedback.
+        Slate id observed for each data in logged bandit data.
 
     reward: array-like, shape (<= n_rounds * len_list,)
-        Reward observed at each slot in each round of the logged bandit feedback, i.e., :math:`r_{t}(k)`.
+        Slot-level rewards, i.e., :math:`r_{i}(l)`.
 
     position: array-like, shape (<= n_rounds * len_list,)
-        Positions of each round and slot in the given logged bandit data.
+        Indices to differentiate positions in a recommendation interface where the actions are presented.
 
     pscore_cascade: array-like, shape (<= n_rounds * len_list,)
-        Action choice probabilities of behavior policy (propensity scores), i.e., :math:`\\pi_b(a_t|x_t)`.
+        Action choice probabilities of behavior policy (propensity scores), i.e., :math:`\\pi_b(a_i|x_i)`.
 
     evaluation_policy_pscore_cascade: array-like, shape (<= n_rounds * len_list,)
-        Action choice probabilities above the slot (:math:`k`) by the evaluation policy, i.e., :math:`\\pi_e(\\{a_{t, j}\\}_{j \\le k}|x_t)`.
+        Action choice probabilities above the slot (:math:`l`) by the evaluation policy, i.e., :math:`\\pi_e(\\{a_{t, j}\\}_{j \\le k}|x_t)`.
 
     """
     _check_slate_ope_inputs(
@@ -764,7 +788,7 @@ def check_rips_inputs(
     )
     # check uniqueness
     if bandit_feedback_df.duplicated(["slate_id", "position"]).sum() > 0:
-        raise ValueError("position must not be duplicated in each slate")
+        raise ValueError("`position` must not be duplicated in each slate")
     # check pscore_cascade structure
     previous_minimum_pscore_cascade = (
         bandit_feedback_df.groupby("slate_id")["pscore_cascade"]
@@ -775,7 +799,9 @@ def check_rips_inputs(
     if (
         previous_minimum_pscore_cascade < bandit_feedback_df["pscore_cascade"]
     ).sum() > 0:
-        raise ValueError("pscore_cascade must be non-increasing sequence in each slate")
+        raise ValueError(
+            "`pscore_cascade` must be non-increasing sequence in each slate"
+        )
     # check pscore_cascade structure of evaluation policy
     previous_minimum_evaluation_policy_pscore_cascade = (
         bandit_feedback_df.groupby("slate_id")["evaluation_policy_pscore_cascade"]
@@ -788,13 +814,111 @@ def check_rips_inputs(
         < bandit_feedback_df["evaluation_policy_pscore_cascade"]
     ).sum() > 0:
         raise ValueError(
-            "evaluation_policy_pscore_cascade must be non-increasing sequence in each slate"
+            "`evaluation_policy_pscore_cascade` must be non-increasing sequence in each slate"
+        )
+
+
+def check_cascade_dr_inputs(
+    n_unique_action: int,
+    slate_id: np.ndarray,
+    action: np.ndarray,
+    reward: np.ndarray,
+    position: np.ndarray,
+    pscore_cascade: np.ndarray,
+    evaluation_policy_pscore_cascade: np.ndarray,
+    q_hat: np.ndarray,
+    evaluation_policy_action_dist: np.ndarray,
+) -> Optional[ValueError]:
+    """Check inputs of SlateCascadeDoublyRobust.
+
+    Parameters
+    -----------
+    n_unique_action: int
+        Number of unique actions.
+
+    slate_id: array-like, shape (<= n_rounds * len_list,)
+        Indices to differentiate slates (i.e., ranking or list of actions)
+
+    action: array-like, (<= n_rounds * len_list,)
+        Actions observed at each slot in a ranking/slate in logged bandit data, i.e., :math:`a_{i}(l)`,
+        which is chosen by the behavior policy :math:`\\pi_b`.
+
+    reward: array-like, shape (<= n_rounds * len_list,)
+        Slot-level rewards observed for each data in logged bandit data, i.e., :math:`r_{i}(l)`.
+
+    position: array-like, shape (<= n_rounds * len_list,)
+        Indices to differentiate slots/positions in a slate/ranking.
+
+    pscore_cascade: array-like, shape (<= n_rounds * len_list,)
+        Probabilities of behavior policy selecting action :math:`a` at position (slot) `k` conditional on the previous actions (presented at position `1` to `k-1`)
+        , i.e., :math:`\\pi_b(a_i(l) | x_i, a_i(1), \\ldots, a_i(l-1))`.
+
+    evaluation_policy_pscore_cascade: array-like, shape (<= n_rounds * len_list,)
+        Probabilities of evaluation policy selecting action :math:`a` at position (slot) `k` conditional on the previous actions (presented at position `1` to `k-1`)
+        , i.e., :math:`\\pi_e(a_i(l) | x_i, a_i(1), \\ldots, a_i(l-1))`.
+
+    q_hat: array-like (<= n_rounds * len_list * n_unique_actions, )
+        :math:`\\hat{Q}_l` used in Cascade-DR.
+        , i.e., :math:`\\hat{Q}_{i,l}(x_i, a_i(1), \\ldots, a_i(l-1), a_i(l)) \\forall a_i(l) \\in \\mathcal{A}`.
+
+    evaluation_policy_action_dist: array-like (<= n_rounds * len_list * n_unique_actions, )
+        Action choice probabilities of evaluation policy for all possible actions
+        , i.e., :math:`\\pi_e(a_i(l) | x_i, a_i(1), \\ldots, a_i(l-1)) \\forall a_i(l) \\in \\mathcal{A}`.
+
+    """
+    check_rips_inputs(
+        slate_id=slate_id,
+        reward=reward,
+        position=position,
+        pscore_cascade=pscore_cascade,
+        evaluation_policy_pscore_cascade=evaluation_policy_pscore_cascade,
+    )
+    check_array(array=action, name="action", expected_dim=1)
+    check_array(
+        array=q_hat,
+        name="q_hat",
+        expected_dim=1,
+    )
+    check_array(
+        array=evaluation_policy_action_dist,
+        name="evaluation_policy_action_dist",
+        expected_dim=1,
+    )
+    if not (
+        np.issubdtype(action.dtype, np.integer)
+        and action.min() >= 0
+        and action.max() < n_unique_action
+    ):
+        raise ValueError(
+            "`action` elements must be integers in the range of [0, n_unique_action)"
+        )
+    if not (
+        slate_id.shape[0]
+        == action.shape[0]
+        == q_hat.shape[0] // n_unique_action
+        == evaluation_policy_action_dist.shape[0] // n_unique_action
+    ):
+        raise ValueError(
+            "Expected `slate_id.shape[0] == action.shape[0] == "
+            "q_hat.shape[0] // n_unique_action == evaluation_policy_action_dist.shape[0] // n_unique_action`, "
+            "but found it False"
+        )
+    evaluation_policy_action_dist_ = evaluation_policy_action_dist.reshape(
+        (-1, n_unique_action)
+    )
+    if not np.allclose(
+        np.ones(evaluation_policy_action_dist_.shape[0]),
+        evaluation_policy_action_dist_.sum(axis=1),
+    ):
+        raise ValueError(
+            "`evaluation_policy_action_dist[i * n_unique_action : (i+1) * n_unique_action]` "
+            "must sum up to one for all i."
         )
 
 
 def sigmoid(x: Union[float, np.ndarray]) -> Union[float, np.ndarray]:
     """Calculate sigmoid function."""
-    return 1.0 / (1.0 + np.exp(-x))
+    return np.exp(np.minimum(x, 0)) / (1.0 + np.exp(-np.abs(x)))
 
 
 def softmax(x: Union[float, np.ndarray]) -> Union[float, np.ndarray]:
